/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tika.parser.msg;

import java.io.IOException;
import java.io.InputStream;

import org.apache.tika.exception.TikaException;
import org.apache.tika.metadata.Metadata;
import org.apache.tika.parser.Parser;

import com.auxilii.msgparser.Message;
import com.auxilii.msgparser.MsgParser;

/**
 * Outlook Msg Parser
 */
public class OutloukMsgParser implements Parser {

    public String parse(InputStream stream, Metadata metadata)
            throws IOException, TikaException {
        MsgParser msgp = new MsgParser();
        Message msg = msgp.parseMsg(stream);
        metadata.add("fromEmail", msg.getFromEmail());
        metadata.add("fromName", msg.getFromName());
        metadata.add("toName", msg.getToName());
        metadata.add("date", msg.getDate().toString());
        metadata.add(Metadata.SUBJECT, msg.getSubject());
        metadata.add("toMail", msg.getToEmail());
        metadata.add("messageId", msg.getMessageId());
        metadata.add("headers", msg.getHeaders());
        metadata.add("body", msg.getBodyText());
        return msg.toString();
    }

}
